@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 11.4's 2.6.37 kernel.
+# This is a kernel build script for openSUSE 11.3's 2.6.34 kernel.
 #
 
 die () {
@@ -60,24 +60,24 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.37.1-1.2.2.src.rpm ]
+if [ ! -r kernel-source-2.6.34.8-0.2.1.src.rpm ]
 then
-    wget http://download.opensuse.org/source/distribution/11.4/repo/oss/suse/src/kernel-source-2.6.37.1-1.2.2.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-source-2.6.34.8-0.2.1.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-source-2.6.37.1-1.2.2.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-source-2.6.37.1-1.2.2.src.rpm || die "Can't install source package."
+rpm --checksig kernel-source-2.6.34.8-0.2.1.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-source-2.6.34.8-0.2.1.src.rpm || die "Can't install source package."
 
-if [ ! -r kernel-default-2.6.37.1-1.2.2.nosrc.rpm ]
+if [ ! -r kernel-default-2.6.34.8-0.2.1.nosrc.rpm ]
 then
-    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-default-2.6.34.7-0.7.1.nosrc.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-default-2.6.34.8-0.2.1.nosrc.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-default-2.6.37.1-1.2.2.nosrc.rpm || die "Can't verify signature."
-rpm -ivh kernel-default-2.6.37.1-1.2.2.nosrc.rpm || die "Can't install source package."
+rpm --checksig kernel-default-2.6.34.8-0.2.1.nosrc.rpm || die "Can't verify signature."
+rpm -ivh kernel-default-2.6.34.8-0.2.1.nosrc.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.1-20110401.tar.gz ]
+if [ ! -r ccs-patch-1.8.1-20110505.tar.gz ]
 then
-    wget -O ccs-patch-1.8.1-20110401.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.1-20110401.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.1-20110505.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.1-20110505.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -92,19 +92,19 @@ patch << "EOF" || die "Can't patch spec file."
 -Name:           kernel-default
 +Name:           ccs-kernel-default
  Summary:        The Standard Kernel
- Version:        2.6.37.1
--Release:        1.2.2
-+Release:        1.2.2_tomoyo_1.8.1
+ Version:        2.6.34.8
+-Release:        0.2.1
++Release:        0.2.1_tomoyo_1.8.1p2
  %if %using_buildservice
  %else
  %endif
-@@ -303,6 +303,11 @@
+@@ -306,6 +306,11 @@
  %endif
  	%_sourcedir/series.conf .. $SYMBOLS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.1-20110401.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.37-suse-11.4.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.1-20110505.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.34-suse-11.3.diff
 +cat config.ccs >> ../config/%cpu_arch_flavor
 +
  cd %kernel_build_dir
